V5.17 If the application framework allows automatic mass parameter assignment (also called automatic variable binding) from the inbound request to a model, verify that security sensitive fields such as accountBalance, role or password are protected from malicious automatic binding.